@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2016-09-28'; # DATE
-our $VERSION = '0.66'; # VERSION
+our $DATE = '2016-10-07'; # DATE
+our $VERSION = '0.67'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -363,8 +363,8 @@ sub _process_script {
                         }
                     } else {
                         my $res;
-                        if (exists $eg->{result}) {
-                            $res = $eg->{result};
+                        if (exists $eg->{example_spec}{result}) {
+                            $res = $eg->{example_spec}{result};
                         } else {
                             my %extra;
                             if ($eg->{example_spec}{argv}) {
@@ -891,7 +891,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.66 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-09-28.
+This document describes version 0.67 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-10-07.
 
 =head1 SYNOPSIS
 
@@ -990,7 +990,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Rinci>.
+Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Perinci>.
 
 =head1 BUGS
 
